% This is the CSE UCONN letterhead class. It can be used in
% conjunction with LaTeX, and the appropriate insignia files,
% to produce a fair reproduction of the UCONN letterhead style.
% Have a look at instructions.pdf for more guidance.

% Copyright (C) 2003 Alexander Russell, acr@cse.uconn.edu

% This program is free software can redistribute it and/or
% modify it under the terms of the GNU General Public License as
% published by the Free Software Foundation; either version 2 of the
% License, or (at your option) any later version.

% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.

% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
% USA


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{cseletter}[2010/10/18 CSE UCONN Letterhead]
\RequirePackage{graphicx}
\RequirePackage{color}
\RequirePackage[absolute]{textpos}

% Setup UCONN official letterhead colors.
\definecolor{UConnNavyBlue}{cmyk}{1,.72,0,.38}
\definecolor{UConnGray}{cmyk}{0,0,0,.6}

% Setup UCONN logo.
\newcommand{\bwuclogo}{\scalebox{.75}{\includegraphics*[clip= 154 351 239 442]{signa3blacksans}}}
\newcommand{\coloruclogo}{\scalebox{.75}{\includegraphics*[clip= 154 351 239 442]{signa3colorsans}}}
\newcommand{\uclogo}{\bwuclogo}

% Setup parameter passing commands:
\newcommand*{\department}[1]{\def\actdepartment{#1}}
\newcommand*{\street}[1]{\def\actstreet{#1}}
\newcommand*{\ubox}[1]{\def\actubox{#1}}
\newcommand*{\city}[1]{\def\actcity{#1}}
\newcommand*{\zipcode}[1]{\def\actzipcode{#1}}
\newcommand*{\areacode}[1]{\def\actareacode{#1}}
\newcommand*{\tel}[1]{\def\acttel{#1}}
\newcommand*{\fax}[1]{\def\actfax{#1}}
\newcommand*{\email}[1]{\def\actemail{#1}}
\newcommand*{\web}[1]{\def\actweb{#1}}
\newcommand*{\marginname}[1]{\def\actname{#1}}
\newcommand*{\margintitlea}[1]{\def\acttitlea{#1}}
\newcommand*{\margintitleb}[1]{\def\acttitleb{#1}}

% Setup default values:
\department{Computer Science \&\\ Engineering}
\street{371 Fairfield Rd.}
\ubox{2155}
\city{Storrs}
\zipcode{06269}
\areacode{860}
\tel{486-3719}
\fax{486-4817}
\email{}
\web{http://www.cse.uconn.edu}
\marginname{}
\margintitlea{}
\margintitleb{}

% Setup the letter head components.
% (N.b. These are supposed to be in Garamond.)
\newcommand{\UCONNname}{\fontsize{20}{22}\usefont{OT1}{ptm}{m}{n}\textcolor{UConnGray}{University of Connecticut}}
\newcommand{\principleidentifier}{\fontsize{20}{22}\usefont{OT1}{ptm}{m}{n}\textcolor{UConnGray}{\textit{School of Engineering}}}
\newcommand{\returnaddressinfo}{\fontsize{10}{12}\usefont{OT1}{ptm}{m}{n}%
  \textcolor{UConnGray}{\textit{An Equal Opportunity Employer}}\\%
  \hspace*{1in}\\%
  \textcolor{UConnGray}{\actstreet, U-\actubox}\\%
  \vspace*{2mm}\textcolor{UConnGray}{\actcity, Connecticut, \actzipcode}\\%
  \textcolor{UConnGray}{Telephone: (\actareacode) \acttel}\\%
  \textcolor{UConnGray}{Facsimile: (\actareacode) \actfax}\\%
  \textcolor{UConnGray}{e-mail: \actemail}\\%
  \textcolor{UConnGray}{web: \actweb}}%
\newcommand{\margintitle}{%
  \begin{minipage}{1.75in}%
    \begin{center}%
      \fontsize{9}{11}\usefont{OT1}{ptm}{m}{n}%
      \textcolor{UConnGray}{\actdepartment}\\%
      \hspace*{1cm}\\%
      \textcolor{UConnGray}{\actname}\\%
      \textcolor{UConnGray}{\textit{\acttitlea}}\\%
      \textcolor{UConnGray}{\textit{\acttitleb}}%
    \end{center}%
  \end{minipage}%
}

% Define length variables.
\newlength{\UCONNnameheight}
\newlength{\returnaddresswidth}
\newlength{\margintitlewidth}
\newlength{\logowidth}
\newlength{\margintitleverticalplace}

                                % Compute the line height of margin titles.
\newlength{\margintitlelineheight}
\settoheight{\margintitlelineheight}{\fontsize{9}{11}\usefont{OT1}{ptm}{m}{n}Computer}

\newcommand{\placeletterheadblocks}{%
                                % Several length/width params of the above we will need to actually lay
                                % these objects out on the page. We compute these below.
  \settoheight{\UCONNnameheight}{\UCONNname}%
  \settowidth{\returnaddresswidth}{\returnaddressinfo}%
  \settowidth{\margintitlewidth}{\margintitle}%
  \settowidth{\logowidth}{\uclogo}%
  \setlength{\margintitleverticalplace}{1.75in}
 \addtolength{\margintitleverticalplace}{-1\margintitlelineheight}
  \begin{textblock*}{\returnaddresswidth}[0,1](.375in,10.625in)%
    \returnaddressinfo%
  \end{textblock*}%
  \begin{textblock*}{\logowidth}[.5,1](1in,1.375in)%
    \uclogo%
  \end{textblock*}%
  \begin{textblock*}{\margintitlewidth}[.5,0](1in,\margintitleverticalplace)%
    \margintitle%
  \end{textblock*}%
}

\DeclareOption{bwlogo}{\renewcommand{\uclogo}{\bwuclogo}}
\DeclareOption{colorlogo}{\renewcommand{\uclogo}{\coloruclogo}}
\DeclareOption{nologo}{\renewcommand{\uclogo}{}}
\ExecuteOptions{bwlogo}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{letter}}
\ProcessOptions\relax

                                % Now load the letter class to handle the remaining options.
\LoadClass[letterpaper]{letter}

\setlength{\textwidth}{5.75in}
\setlength{\textheight}{7in}
\setlength{\evensidemargin}{1in}
\setlength{\oddsidemargin}{1in}

                                % Set up the first page style.
\renewcommand{\ps@firstpage}{%
  \setlength{\headheight}{\UCONNnameheight}
  \setlength{\topmargin}{-.25in}%
  \addtolength{\topmargin}{-\UCONNnameheight}%
  \renewcommand{\@oddhead}{\parbox[t]{5in}{\UCONNname\\%
      \principleidentifier}}%
  \renewcommand{\@oddfoot}\@empty%
  \setlength{\headsep}{1in}%
  \addtolength{\headsep}{-1\headheight}%
  \addtolength{\headsep}{-1\topmargin}%
}

                                % Set up the 2ff. page style.
\renewcommand{\ps@plain}{%
  \renewcommand{\@oddhead}\@empty%
  \renewcommand{\@oddfoot}{\normalfont\hfil\thepage\hfil}%
  \renewcommand{\@evenfoot}{\normalfont\hfil\thepage\hfil}%
  \setlength{\headsep}{0in}%
  \setlength{\topmargin}{0in}%
}

% Define the ucletter environment.
\newenvironment{ucletter}[1]{\begin{letter}{#1}\placeletterheadblocks}{\end{letter}}
